@@ -36,5 +36,5 @@ run ${LIBTOOLIZE:-libtoolize} --copy --force
 run ${INTLTOOLIZE:-intltoolize} --force --copy
 #run ${GTKDOCIZE:-gtkdocize} --copy
 run ${AUTOHEADER:-autoheader}
-run ${AUTOMAKE:-automake} --add-missing --foreign --copy
+run ${AUTOMAKE:-automake} --add-missing --copy
 run ${AUTOCONF:-autoconf}
