@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -234,6 +234,8 @@ invoke (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
     priv = CUT_ITERATED_TEST_GET_PRIVATE(test);
 
     value = cut_test_data_get_value(priv->data);
+    if (cut_run_context_get_stop_before_test(run_context))
+        G_BREAKPOINT();
     priv->iterated_test_function(value);
 }
 
