@@ -8,7 +8,7 @@ G_BEGIN_DECLS
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
-#define g_marshal_value_peek_char(v)     g_value_get_char (v)
+#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
 #define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
 #define g_marshal_value_peek_int(v)      g_value_get_int (v)
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
@@ -489,6 +489,59 @@ _gcut_marshal_VOID__OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
+/* VOID:STRING,FLAGS,STRING,UINT,STRING,POINTER,STRING (../gcutter/gcut-marshalers.list:11) */
+extern void _gcut_marshal_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING (GClosure     *closure,
+                                                                                GValue       *return_value,
+                                                                                guint         n_param_values,
+                                                                                const GValue *param_values,
+                                                                                gpointer      invocation_hint,
+                                                                                gpointer      marshal_data);
+void
+_gcut_marshal_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING (GClosure     *closure,
+                                                                    GValue       *return_value G_GNUC_UNUSED,
+                                                                    guint         n_param_values,
+                                                                    const GValue *param_values,
+                                                                    gpointer      invocation_hint G_GNUC_UNUSED,
+                                                                    gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING) (gpointer     data1,
+                                                                                     gpointer     arg_1,
+                                                                                     guint        arg_2,
+                                                                                     gpointer     arg_3,
+                                                                                     guint        arg_4,
+                                                                                     gpointer     arg_5,
+                                                                                     gpointer     arg_6,
+                                                                                     gpointer     arg_7,
+                                                                                     gpointer     data2);
+  register GMarshalFunc_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 8);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_FLAGS_STRING_UINT_STRING_POINTER_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_flags (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_uint (param_values + 4),
+            g_marshal_value_peek_string (param_values + 5),
+            g_marshal_value_peek_pointer (param_values + 6),
+            g_marshal_value_peek_string (param_values + 7),
+            data2);
+}
+
 G_END_DECLS
 
 #endif /* ___gcut_marshal_MARSHAL_H__ */
